@@ -112,6 +112,11 @@ class GPGSigner(Signer):
             gpg_datastore = os.environ.get("DSV_GPG_DATASTORE")
             if gpg_datastore:
                 self.homedir = Path(gpg_datastore)
+        if not self.homedir:
+            gnupghome = os.environ.get("GNUPGHOME")
+            if gnupghome:
+                self.homedir = Path(gnupghome)
+                LOGGER.warning("Using GNUPGHOME: %s", self.homedir)
         if not self.homedir:
             self.homedir = Path.home().joinpath(".gnupg")
             LOGGER.warning("Using default GNUPGHOME: %s", self.homedir)
