@@ -74,7 +74,7 @@ def config_digest_canonical(request) -> FormattedSHA256:
 
 @pytest.fixture
 def config_digest_signed(request) -> FormattedSHA256:
-    """"Provides the digest value of the signed sample image configuration."""
+    """ "Provides the digest value of the signed sample image configuration."""
     return FormattedSHA256.parse(
         get_test_data(request, __name__, "config_signed.json.digest", "r")
     )
@@ -117,13 +117,13 @@ def signature(request) -> str:
     return get_test_data(request, __name__, "signature", "r")
 
 
-def test___init__(image_config: ImageConfig, image_config_signed: ImageConfig):
+async def test___init__(image_config: ImageConfig, image_config_signed: ImageConfig):
     """Test that signed and unsigned configurations can be instantiated."""
     assert image_config
     assert image_config_signed
 
 
-def test___bytes__(
+async def test___bytes__(
     image_config: ImageConfig,
     image_config_signed: ImageConfig,
     json_bytes: bytes,
@@ -134,7 +134,7 @@ def test___bytes__(
     assert bytes(image_config_signed) == json_bytes_signed
 
 
-def test___str__(
+async def test___str__(
     image_config: ImageConfig,
     image_config_signed: ImageConfig,
     json_bytes: bytes,
@@ -145,7 +145,7 @@ def test___str__(
     assert str(image_config_signed) == json_bytes_signed.decode("utf-8")
 
 
-def test__get_labels():
+async def test__get_labels():
     """Test that labels are able to be retrieved."""
     # Uppercase 'C'
     assert ImageConfig._get_labels(json.loads('{"Config":{"Labels":{"x":"5"}}}')) == {
@@ -161,7 +161,7 @@ def test__get_labels():
     assert ImageConfig._get_labels(json.loads('{"Config":{}}')) == {}
 
 
-def test__normalize():
+async def test__normalize():
     """Test that signed and unsigned configuration can be normalized."""
     # Missing 'Labels'
     assert ImageConfig._normalize(json.loads('{"Config":{}}')) == {
@@ -184,7 +184,7 @@ def test__normalize():
     ) == {"Config": {"Labels": {"signatures": '[{"y":"4"}]', "x": "5"}}}
 
 
-def test_get_bytes(
+async def test_get_bytes(
     image_config: ImageConfig,
     image_config_signed: ImageConfig,
     json_bytes: bytes,
@@ -195,7 +195,7 @@ def test_get_bytes(
     assert image_config_signed.get_bytes() == json_bytes_signed
 
 
-def test_get_bytes_canonical(
+async def test_get_bytes_canonical(
     image_config: ImageConfig,
     image_config_signed: ImageConfig,
     json_bytes_canonical: bytes,
@@ -206,7 +206,7 @@ def test_get_bytes_canonical(
     assert image_config_signed.get_bytes_canonical() == json_bytes_signed_canonical
 
 
-def test_get_digest(
+async def test_get_digest(
     config_digest: str,
     config_digest_signed: str,
     image_config: ImageConfig,
@@ -217,7 +217,7 @@ def test_get_digest(
     assert image_config_signed.get_digest() == config_digest_signed
 
 
-def test_get_digest_canonical(
+async def test_get_digest_canonical(
     config_digest_canonical: str,
     config_digest_signed_canonical: str,
     image_config: ImageConfig,
@@ -228,7 +228,7 @@ def test_get_digest_canonical(
     assert image_config_signed.get_digest_canonical() == config_digest_signed_canonical
 
 
-def test_get_image_layers(
+async def test_get_image_layers(
     image_config: ImageConfig, image_config_signed: ImageConfig, image_layers: List
 ):
     """Test image layer preservation for signed and unsigned configurations."""
@@ -236,7 +236,7 @@ def test_get_image_layers(
     assert image_config_signed.get_image_layers() == image_layers
 
 
-def test_clear_signature_list(
+async def test_clear_signature_list(
     image_config: ImageConfig, image_config_signed: ImageConfig
 ):
     """Test signature data parsing for signed and unsigned configurations."""
@@ -248,7 +248,7 @@ def test_clear_signature_list(
     assert not signatures_unsigned
 
 
-def test_get_signature_list(
+async def test_get_signature_list(
     config_digest_canonical: str,
     image_config: ImageConfig,
     image_config_signed: ImageConfig,
@@ -279,9 +279,9 @@ async def test_sign(
         passphrase=gnupg_keypair.passphrase,
         homedir=gnupg_keypair.gnupg_home,
     )
-    sig = await image_config.sign(signer)
+    sig = await image_config.sign(signer=signer)
     assert "PGP SIGNATURE" in sig
-    sig_signed = await image_config_signed.sign(signer)
+    sig_signed = await image_config_signed.sign(signer=signer)
     assert "PGP SIGNATURE" in sig_signed
 
     # Previously unsigned configurations should now contain the new signature.
@@ -315,9 +315,11 @@ async def test_sign_endorse(
         passphrase=gnupg_keypair.passphrase,
         homedir=gnupg_keypair.gnupg_home,
     )
-    sig = await image_config.sign(signer, SignatureTypes.ENDORSE)
+    sig = await image_config.sign(signature_type=SignatureTypes.ENDORSE, signer=signer)
     assert "PGP SIGNATURE" in sig
-    sig_signed = await image_config_signed.sign(signer, SignatureTypes.ENDORSE)
+    sig_signed = await image_config_signed.sign(
+        signature_type=SignatureTypes.ENDORSE, signer=signer
+    )
     assert "PGP SIGNATURE" in sig_signed
 
     # Previously unsigned configurations should now contain the new signature.
@@ -349,9 +351,11 @@ async def test_sign_resign(
         passphrase=gnupg_keypair.passphrase,
         homedir=gnupg_keypair.gnupg_home,
     )
-    sig = await image_config.sign(signer, SignatureTypes.RESIGN)
+    sig = await image_config.sign(signature_type=SignatureTypes.RESIGN, signer=signer)
     assert "PGP SIGNATURE" in sig
-    sig_signed = await image_config_signed.sign(signer, SignatureTypes.RESIGN)
+    sig_signed = await image_config_signed.sign(
+        signature_type=SignatureTypes.RESIGN, signer=signer
+    )
     assert "PGP SIGNATURE" in sig_signed
 
     # Previously unsigned configurations should now contain the new signature.
@@ -383,7 +387,7 @@ async def test_sign_endorse_recursive(image_config: ImageConfig):
     ):
         action = f"X{signature_type.name}"
         signer = FakeSigner(f"[{iteration}-{action: <8}: {{0}}]")
-        await config.sign(signer, signature_type)
+        await config.sign(signature_type=signature_type, signer=signer)
         stack.append({"name": f"{iteration}-{action}", "image_config": config})
 
     iterations = 6
@@ -408,7 +412,7 @@ async def test_sign_endorse_recursive(image_config: ImageConfig):
                 if f"X{SignatureTypes.ENDORSE.name}" in signature.signature:
                     # Endorsement digests should include all entities of a lower order.
                     temp = frame["image_config"].clone()
-                    temp.set_signature_list(temp.get_signature_list()[:sig])
+                    temp.set_signature_list(signatures=temp.get_signature_list()[:sig])
                     assert signature.digest == temp.get_digest_canonical()
                     assert temp.get_digest_canonical() in signature.signature
                 else:
@@ -453,7 +457,7 @@ async def test_verify_signatures(
     assert str(exception.value) == "Image does not contain any signatures!"
 
     # Sign a previously unsigned configuration, so that only the new signature type is present.
-    signature = await image_config.sign(signer)
+    signature = await image_config.sign(signer=signer)
 
     # Attempt to verify the signatures using the default trust store ...
     response = await image_config.verify_signatures()
@@ -484,7 +488,7 @@ async def test_verify_signatures_manipulated_signatures(
     )
 
     # Add a single signature ...
-    await image_config.sign(signer)
+    await image_config.sign(signer=signer)
     response = await image_config.verify_signatures(
         signer_kwargs={GPGSigner.__name__: {"homedir": gnupg_keypair.gnupg_home}}
     )
@@ -497,7 +501,7 @@ async def test_verify_signatures_manipulated_signatures(
         digest=FormattedSHA256.calculate(b"tampertampertamper"),
         signature=temp[0].signature,
     )
-    image_config.set_signature_list(temp)
+    image_config.set_signature_list(signatures=temp)
 
     # An exception should be raised if digest value from the signature does not match the canonical digest of the image
     # configuration (without any signatures).
@@ -506,8 +510,8 @@ async def test_verify_signatures_manipulated_signatures(
     assert str(exception.value).startswith("Image config canonical digest mismatch:")
 
     # Restore the unmodified signature and endorse ...
-    image_config.set_signature_list(signatures)
-    await image_config.sign(signer, SignatureTypes.ENDORSE)
+    image_config.set_signature_list(signatures=signatures)
+    await image_config.sign(signature_type=SignatureTypes.ENDORSE, signer=signer)
     response = await image_config.verify_signatures(
         signer_kwargs={GPGSigner.__name__: {"homedir": gnupg_keypair.gnupg_home}}
     )
@@ -520,7 +524,7 @@ async def test_verify_signatures_manipulated_signatures(
         digest=FormattedSHA256.calculate(b"tampertampertamper"),
         signature=temp[1].signature,
     )
-    image_config.set_signature_list(temp)
+    image_config.set_signature_list(signatures=temp)
 
     # An exception should be raised if digest value from the signature does not match the canonical digest of the image
     # configuration (including the first signature).
@@ -541,7 +545,7 @@ async def test_minimal(gnupg_keypair: GnuPGKeypair):
     # Note: At a minimum, [Cc]onfig key must exist with non-null value
     image_config = ImageConfig(b'{"Config":{}}')
     config_digest_canonical = image_config.get_digest_canonical()
-    signature = await image_config.sign(signer)
+    signature = await image_config.sign(signer=signer)
     assert "PGP SIGNATURE" in signature
 
     # A signature should always be able to be added ...
